about summary refs log tree commit diff stats
path: root/src/xmpp/iq.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/xmpp/iq.c')
-rw-r--r--src/xmpp/iq.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/xmpp/iq.c b/src/xmpp/iq.c
index 6903a412..aa5dc046 100644
--- a/src/xmpp/iq.c
+++ b/src/xmpp/iq.c
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
  * This file is part of Profanity.
  *
  * Profanity is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Profanity is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
@@ -46,7 +46,7 @@
 
 #include <strophe.h>
 
-#include "profanity.h"
+#include "profani-tty.h"
 #include "log.h"
 #include "config/preferences.h"
 #include "event/server_events.h"
@@ -1649,7 +1649,7 @@ _version_get_handler(xmpp_stanza_t* const stanza)
     xmpp_stanza_t* name = xmpp_stanza_new(ctx);
     xmpp_stanza_set_name(name, "name");
     xmpp_stanza_t* name_txt = xmpp_stanza_new(ctx);
-    xmpp_stanza_set_text(name_txt, is_custom_client ? client : "Profanity");
+    xmpp_stanza_set_text(name_txt, is_custom_client ? client : "Profani-tty");
     xmpp_stanza_add_child(name, name_txt);
     xmpp_stanza_add_child(query, name);
     bool include_os = prefs_get_boolean(PREF_REVEAL_OS) && !is_custom_client;
@@ -4,20 +4,20 @@
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
@@ -4,20 +4,20 @@
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -4,20 +4,20 @@
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the